package com.bzd.web.controller.daas;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.common.utils.DateUtils;
import com.bzd.common.utils.uuid.IdUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.daas.SDaasChannelManagementService;

import java.util.List;

/**
*
* 渠道管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "daas/sdaaschannelmanagement")
public class SDaasChannelManagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "daas";

    @Autowired
    private SDaasChannelManagementService sDaasChannelManagementService;

    /**
    * 渠道管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("daas:ds:view")
    @GetMapping("/sDaasChannelManagementAdd")
    public String add() {
        return prefix + "/SDaasChannelManagementAdd";
    }

    /**
    * 渠道管理表 新增
    *
    * @return
    */
    @Log(title = "渠道管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDaasChannelManagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            pd.put("channelCode", IdUtils.randomUUID());
            pd.put("createdBy", getSysUser().getUserId()) ;
            pd.put("createdAt",DateUtils.getTime());
            Integer result = sDaasChannelManagementService.addSDaasChannelManagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 渠道管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("daas:ds:view")
    @GetMapping("/sDaasChannelManagementView")
    public String sdaaschannelmanagementListView() {
        return prefix + "/SDaasChannelManagementList";
    }

    /**
    * 渠道管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("daas:ds:list")
    @PostMapping("/sDaasChannelManagementList")
    @ResponseBody
    public TableDataInfo sdaaschannelmanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDaasChannelManagementService.findSDaasChannelManagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 渠道管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("daas:ds:remove")
    @Log(title = "渠道管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDaasChannelManagementRemove")
    @ResponseBody
    public AjaxResult sdaaschannelmanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDaasChannelManagementService.SDaasChannelManagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 渠道管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("daas:ds:edit")
    @GetMapping("/sDaasChannelManagementEdit/{id}")
    public String sdaaschannelmanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDaasChannelManagementService.findSDaasChannelManagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SDaasChannelManagementPageEdit";
        }
        return prefix+ "/SDaasChannelManagementEdit";
    }

    /**
    * 渠道管理表保存修改的数据
    */
    @RequiresPermissions("daas:ds:edit")
    @Log(title = "渠道管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDaasChannelManagementEdit")
    @ResponseBody
    public AjaxResult sdaaschannelmanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDaasChannelManagementService.updateSDaasChannelManagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdaaschannelmanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdaaschannelmanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
