package com.bzd.web.controller.ddgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.common.utils.DateUtils;
import com.bzd.common.utils.uuid.IdUtils;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.security.SecurityProperties;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.ddgl.SDdglOrderStoreService;

import java.util.Date;
import java.util.List;

/**
*
* 门店订单表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "ddgl/sddglorderstore")
public class SDdglOrderStoreController extends BaseController {

    // 页面跳转前缀
    private String prefix = "ddgl";

    @Autowired
    private SDdglOrderStoreService sDdglOrderStoreService;

    /**
    * 门店订单表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("ddgl:dd:view")
    @GetMapping("/sDdglOrderStoreAdd")
    public String add() {
        return prefix + "/SDdglOrderStoreAdd";
    }

    /**
    * 门店订单表 新增
    *
    * @return
    */
    @Log(title = "门店订单表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDdglOrderStoreAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            pd.put("orderId", IdUtils.randomUUID());
            pd.put("orderStatus","待上传处方");
            pd.put("deliveryStatus","待派单");
            pd.put("systemLoginUserId", getSysUser().getUserId()) ;
            pd.put("memberName",getSysUser().getLoginName());
            pd.put("memberId",getSysUser().getUserId());
            pd.put("channelOrderNo",IdUtils.randomUUID());
            pd.put("psoSaleOrderNo",IdUtils.randomUUID());
            pd.put("settlementId",IdUtils.randomUUID());
            pd.put("settlementCode",IdUtils.randomUUID());
            pd.put("consumptionTime", DateUtils.getTime());
            pd.put("orderDate",DateUtils.getTime());
            Integer result = sDdglOrderStoreService.addSDdglOrderStore(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店订单表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("ddgl:dd:view")
    @GetMapping("/sDdglOrderStoreView")
    public String sddglorderstoreListView() {
        return prefix + "/SDdglOrderStoreList";
    }

    /**
    * 门店订单表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ddgl:dd:list")
    @PostMapping("/sDdglOrderStoreList")
    @ResponseBody
    public TableDataInfo sddglorderstoreList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDdglOrderStoreService.findSDdglOrderStoreList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店订单表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ddgl:dd:remove")
    @Log(title = "门店订单表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDdglOrderStoreRemove")
    @ResponseBody
    public AjaxResult sddglorderstoreRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDdglOrderStoreService.SDdglOrderStoreRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店订单表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("ddgl:dd:edit")
    @GetMapping("/sDdglOrderStoreEdit/{id}")
    public String sddglorderstoreView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDdglOrderStoreService.findSDdglOrderStoreList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SDdglOrderStorePageEdit";
        }
        return prefix+ "/SDdglOrderStoreEdit";
    }

    /**
    * 门店订单表保存修改的数据
    */
    @RequiresPermissions("ddgl:dd:edit")
    @Log(title = "门店订单表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDdglOrderStoreEdit")
    @ResponseBody
    public AjaxResult sddglorderstoreEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDdglOrderStoreService.updateSDdglOrderStore(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sddglorderstore with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sddglorderstore with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
