package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpSjdcFollowUpStatisticsService;

import java.util.List;

/**
*
* 随访统计表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpsjdcfollowupstatistics")
public class SDtpSjdcFollowUpStatisticsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpSjdcFollowUpStatisticsService sDtpSjdcFollowUpStatisticsService;

    /**
    * 随访统计表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpSjdcFollowUpStatisticsAdd")
    public String add() {
        return prefix + "/sfrw/SDtpSjdcFollowUpStatisticsAdd";
    }

    /**
    * 随访统计表 新增
    *
    * @return
    */
    @Log(title = "随访统计表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpSjdcFollowUpStatisticsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpSjdcFollowUpStatisticsService.addSDtpSjdcFollowUpStatistics(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 随访统计表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpSjdcFollowUpStatisticsView")
    public String sdtpsjdcfollowupstatisticsListView() {
        return prefix + "/sfrw/SDtpSjdcFollowUpStatisticsList";
    }

    /**
    * 随访统计表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:list")
    @PostMapping("/sDtpSjdcFollowUpStatisticsList")
    @ResponseBody
    public TableDataInfo sdtpsjdcfollowupstatisticsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpSjdcFollowUpStatisticsService.findSDtpSjdcFollowUpStatisticsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 随访统计表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "随访统计表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpSjdcFollowUpStatisticsRemove")
    @ResponseBody
    public AjaxResult sdtpsjdcfollowupstatisticsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpSjdcFollowUpStatisticsService.SDtpSjdcFollowUpStatisticsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 随访统计表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpSjdcFollowUpStatisticsEdit/{id}")
    public String sdtpsjdcfollowupstatisticsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpSjdcFollowUpStatisticsService.findSDtpSjdcFollowUpStatisticsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sfrw/SDtpSjdcFollowUpStatisticsPageEdit";
        }
        return prefix+ "/sfrw/SDtpSjdcFollowUpStatisticsEdit";
    }

    /**
    * 随访统计表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "随访统计表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpSjdcFollowUpStatisticsEdit")
    @ResponseBody
    public AjaxResult sdtpsjdcfollowupstatisticsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpSjdcFollowUpStatisticsService.updateSDtpSjdcFollowUpStatistics(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpsjdcfollowupstatistics with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpsjdcfollowupstatistics with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
