package com.bzd.web.controller.dtp;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.dtp.SDtpZskcxDrugInstructionsService;

import java.util.List;

/**
*
* 药品说明书表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "dtp/sdtpzskcxdruginstructions")
public class SDtpZskcxDrugInstructionsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "dtp";

    @Autowired
    private SDtpZskcxDrugInstructionsService sDtpZskcxDrugInstructionsService;

    /**
    * 药品说明书表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxDrugInstructionsAdd")
    public String add() {
        return prefix + "/sfrw/SDtpZskcxDrugInstructionsAdd";
    }

    /**
    * 药品说明书表 新增
    *
    * @return
    */
    @Log(title = "药品说明书表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sDtpZskcxDrugInstructionsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sDtpZskcxDrugInstructionsService.addSDtpZskcxDrugInstructions(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 药品说明书表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("dtp:dtp:view")
    @GetMapping("/sDtpZskcxDrugInstructionsView")
    public String sdtpzskcxdruginstructionsListView() {
        return prefix + "/sfrw/SDtpZskcxDrugInstructionsList";
    }

    /**
    * 药品说明书表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:list")
    @PostMapping("/sDtpZskcxDrugInstructionsList")
    @ResponseBody
    public TableDataInfo sdtpzskcxdruginstructionsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sDtpZskcxDrugInstructionsService.findSDtpZskcxDrugInstructionsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 药品说明书表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:remove")
    @Log(title = "药品说明书表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sDtpZskcxDrugInstructionsRemove")
    @ResponseBody
    public AjaxResult sdtpzskcxdruginstructionsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sDtpZskcxDrugInstructionsService.SDtpZskcxDrugInstructionsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 药品说明书表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("dtp:dtp:edit")
    @GetMapping("/sDtpZskcxDrugInstructionsEdit/{id}")
    public String sdtpzskcxdruginstructionsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sDtpZskcxDrugInstructionsService.findSDtpZskcxDrugInstructionsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/sfrw/SDtpZskcxDrugInstructionsPageEdit";
        }
        return prefix+ "/sfrw/SDtpZskcxDrugInstructionsEdit";
    }

    /**
    * 药品说明书表保存修改的数据
    */
    @RequiresPermissions("dtp:dtp:edit")
    @Log(title = "药品说明书表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sDtpZskcxDrugInstructionsEdit")
    @ResponseBody
    public AjaxResult sdtpzskcxdruginstructionsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sDtpZskcxDrugInstructionsService.updateSDtpZskcxDrugInstructions(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sdtpzskcxdruginstructions with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sdtpzskcxdruginstructions with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
