package com.bzd.web.controller.mdyy;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.common.utils.DateUtils;
import com.bzd.common.utils.uuid.IdUtils;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.mdyy.SMdyyglMdygxxStoreemployeeinfoService;

import java.util.List;

/**
*
* 门店员工信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "mdyygl/smdyyglmdygxxstoreemployeeinfo")
public class SMdyyglMdygxxStoreemployeeinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "mdyy";

    @Autowired
    private SMdyyglMdygxxStoreemployeeinfoService sMdyyglMdygxxStoreemployeeinfoService;

    /**
    * 门店员工信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("mdyygl:mdyy:view")
    @GetMapping("/sMdyyglMdygxxStoreemployeeinfoAdd")
    public String add() {
        return prefix + "/SMdyyglMdygxxStoreemployeeinfoAdd";
    }

    /**
    * 门店员工信息表 新增
    *
    * @return
    */
    @Log(title = "门店员工信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sMdyyglMdygxxStoreemployeeinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            pd.put("employeeCode", IdUtils.fastUUID());//员工编码
            pd.put("jdDate", DateUtils.getTime());//建党日期

            Integer result = sMdyyglMdygxxStoreemployeeinfoService.addSMdyyglMdygxxStoreemployeeinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店员工信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("mdyygl:mdyy:view")
    @GetMapping("/sMdyyglMdygxxStoreemployeeinfoView")
    public String smdyyglmdygxxstoreemployeeinfoListView() {
        return prefix + "/SMdyyglMdygxxStoreemployeeinfoList";
    }

    /**
    * 门店员工信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("mdyygl:mdyy:list")
    @PostMapping("/sMdyyglMdygxxStoreemployeeinfoList")
    @ResponseBody
    public TableDataInfo smdyyglmdygxxstoreemployeeinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sMdyyglMdygxxStoreemployeeinfoService.findSMdyyglMdygxxStoreemployeeinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店员工信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("mdyygl:mdyy:remove")
    @Log(title = "门店员工信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sMdyyglMdygxxStoreemployeeinfoRemove")
    @ResponseBody
    public AjaxResult smdyyglmdygxxstoreemployeeinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sMdyyglMdygxxStoreemployeeinfoService.SMdyyglMdygxxStoreemployeeinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店员工信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("mdyygl:mdyy:edit")
    @GetMapping("/sMdyyglMdygxxStoreemployeeinfoEdit/{id}")
    public String smdyyglmdygxxstoreemployeeinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sMdyyglMdygxxStoreemployeeinfoService.findSMdyyglMdygxxStoreemployeeinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SMdyyglMdygxxStoreemployeeinfoPageEdit";
        }
        return prefix+ "/SMdyyglMdygxxStoreemployeeinfoEdit";
    }

    /**
    * 门店员工信息表保存修改的数据
    */
    @RequiresPermissions("mdyygl:mdyy:edit")
    @Log(title = "门店员工信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sMdyyglMdygxxStoreemployeeinfoEdit")
    @ResponseBody
    public AjaxResult smdyyglmdygxxstoreemployeeinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sMdyyglMdygxxStoreemployeeinfoService.updateSMdyyglMdygxxStoreemployeeinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表smdyyglmdygxxstoreemployeeinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表smdyyglmdygxxstoreemployeeinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
