package com.bzd.web.controller.xtsz;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xtsz.SXtszMdzhglAccountmanagementService;

import java.util.List;

/**
*
* 账号管理 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-18
*/
@Controller
@RequestMapping(value = "xtsz/sxtszmdzhglaccountmanagement")
public class SXtszMdzhglAccountmanagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xtsz";

    @Autowired
    private SXtszMdzhglAccountmanagementService sXtszMdzhglAccountmanagementService;

    /**
    * 账号管理 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xtsz:xt:view")
    @GetMapping("/sXtszMdzhglAccountmanagementAdd")
    public String add() {
        return prefix + "/SXtszMdzhglAccountmanagementAdd";
    }

    /**
    * 账号管理 新增
    *
    * @return
    */
    @Log(title = "账号管理新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXtszMdzhglAccountmanagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXtszMdzhglAccountmanagementService.addSXtszMdzhglAccountmanagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 账号管理 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xtsz:xt:view")
    @GetMapping("/sXtszMdzhglAccountmanagementView")
    public String sxtszmdzhglaccountmanagementListView() {
        return prefix + "/SXtszMdzhglAccountmanagementList";
    }

    /**
    * 账号管理 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:list")
    @PostMapping("/sXtszMdzhglAccountmanagementList")
    @ResponseBody
    public TableDataInfo sxtszmdzhglaccountmanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXtszMdzhglAccountmanagementService.findSXtszMdzhglAccountmanagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 账号管理 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:remove")
    @Log(title = "账号管理删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXtszMdzhglAccountmanagementRemove")
    @ResponseBody
    public AjaxResult sxtszmdzhglaccountmanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXtszMdzhglAccountmanagementService.SXtszMdzhglAccountmanagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 账号管理 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:edit")
    @GetMapping("/sXtszMdzhglAccountmanagementEdit/{id}")
    public String sxtszmdzhglaccountmanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXtszMdzhglAccountmanagementService.findSXtszMdzhglAccountmanagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SXtszMdzhglAccountmanagementPageEdit";
        }
        return prefix+ "/SXtszMdzhglAccountmanagementEdit";
    }

    /**
    * 账号管理保存修改的数据
    */
    @RequiresPermissions("xtsz:xt:edit")
    @Log(title = "账号管理修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXtszMdzhglAccountmanagementEdit")
    @ResponseBody
    public AjaxResult sxtszmdzhglaccountmanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXtszMdzhglAccountmanagementService.updateSXtszMdzhglAccountmanagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxtszmdzhglaccountmanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxtszmdzhglaccountmanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
