package com.bzd.web.controller.xtsz;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xtsz.SXtszMdzhglStoremanagementService;

import java.util.List;

/**
*
* 门店管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-18
*/
@Controller
@RequestMapping(value = "xtsz/sxtszmdzhglstoremanagement")
public class SXtszMdzhglStoremanagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xtsz";

    @Autowired
    private SXtszMdzhglStoremanagementService sXtszMdzhglStoremanagementService;

    /**
    * 门店管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xtsz:xt:view")
    @GetMapping("/sXtszMdzhglStoremanagementAdd")
    public String add() {
        return prefix + "/SXtszMdzhglStoremanagementAdd";
    }

    /**
    * 门店管理表 新增
    *
    * @return
    */
    @Log(title = "门店管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXtszMdzhglStoremanagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXtszMdzhglStoremanagementService.addSXtszMdzhglStoremanagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xtsz:xt:view")
    @GetMapping("/sXtszMdzhglStoremanagementView")
    public String sxtszmdzhglstoremanagementListView() {
        return prefix + "/SXtszMdzhglStoremanagementList";
    }

    /**
    * 门店管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:list")
    @PostMapping("/sXtszMdzhglStoremanagementList")
    @ResponseBody
    public TableDataInfo sxtszmdzhglstoremanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXtszMdzhglStoremanagementService.findSXtszMdzhglStoremanagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:remove")
    @Log(title = "门店管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXtszMdzhglStoremanagementRemove")
    @ResponseBody
    public AjaxResult sxtszmdzhglstoremanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXtszMdzhglStoremanagementService.SXtszMdzhglStoremanagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xtsz:xt:edit")
    @GetMapping("/sXtszMdzhglStoremanagementEdit/{id}")
    public String sxtszmdzhglstoremanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXtszMdzhglStoremanagementService.findSXtszMdzhglStoremanagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SXtszMdzhglStoremanagementPageEdit";
        }
        return prefix+ "/SXtszMdzhglStoremanagementEdit";
    }

    /**
    * 门店管理表保存修改的数据
    */
    @RequiresPermissions("xtsz:xt:edit")
    @Log(title = "门店管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXtszMdzhglStoremanagementEdit")
    @ResponseBody
    public AjaxResult sxtszmdzhglstoremanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXtszMdzhglStoremanagementService.updateSXtszMdzhglStoremanagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxtszmdzhglstoremanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxtszmdzhglstoremanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
