package com.bzd.web.controller.xzgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.xzgl.SXzglDownloadManagementService;

import java.util.List;

/**
*
* 下载管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "xzgl/sxzgldownloadmanagement")
public class SXzglDownloadManagementController extends BaseController {

    // 页面跳转前缀
    private String prefix = "xzgl";

    @Autowired
    private SXzglDownloadManagementService sXzglDownloadManagementService;

    /**
    * 下载管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("xzgl:xz:view")
    @GetMapping("/sXzglDownloadManagementAdd")
    public String add() {
        return prefix + "/SXzglDownloadManagementAdd";
    }

    /**
    * 下载管理表 新增
    *
    * @return
    */
    @Log(title = "下载管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sXzglDownloadManagementAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sXzglDownloadManagementService.addSXzglDownloadManagement(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 下载管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("xzgl:xz:view")
    @GetMapping("/sXzglDownloadManagementView")
    public String sxzgldownloadmanagementListView() {
        return prefix + "/SXzglDownloadManagementList";
    }

    /**
    * 下载管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xzgl:xz:list")
    @PostMapping("/sXzglDownloadManagementList")
    @ResponseBody
    public TableDataInfo sxzgldownloadmanagementList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sXzglDownloadManagementService.findSXzglDownloadManagementList(pd);
        return getDataTable(pageData);
    }

    /**
    * 下载管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xzgl:xz:remove")
    @Log(title = "下载管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sXzglDownloadManagementRemove")
    @ResponseBody
    public AjaxResult sxzgldownloadmanagementRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sXzglDownloadManagementService.SXzglDownloadManagementRemove(pd);
        return toAjax(integer);
    }

    /**
    * 下载管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("xzgl:xz:edit")
    @GetMapping("/sXzglDownloadManagementEdit/{id}")
    public String sxzgldownloadmanagementView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sXzglDownloadManagementService.findSXzglDownloadManagementList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SXzglDownloadManagementPageEdit";
        }
        return prefix+ "/SXzglDownloadManagementEdit";
    }

    /**
    * 下载管理表保存修改的数据
    */
    @RequiresPermissions("xzgl:xz:edit")
    @Log(title = "下载管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sXzglDownloadManagementEdit")
    @ResponseBody
    public AjaxResult sxzgldownloadmanagementEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sXzglDownloadManagementService.updateSXzglDownloadManagement(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表sxzgldownloadmanagement with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表sxzgldownloadmanagement with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
