package com.bzd.web.controller.zlgl;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.common.utils.uuid.IdUtils;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.zlgl.SZlglCfdjSaleprescriptioninfoService;

import java.util.List;

/**
*
* 处方登记记录 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-15
*/
@Controller
@RequestMapping(value = "zlgl/szlglcfdjsaleprescriptioninfo")
public class SZlglCfdjSaleprescriptioninfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "zlgl";

    @Autowired
    private SZlglCfdjSaleprescriptioninfoService sZlglCfdjSaleprescriptioninfoService;

    /**
    * 处方登记记录 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("zlgl:zl:view")
    @GetMapping("/sZlglCfdjSaleprescriptioninfoAdd")
    public String add() {
        return prefix + "/SZlglCfdjSaleprescriptioninfoAdd";
    }

    /**
    * 处方登记记录 新增
    *
    * @return
    */
    @Log(title = "处方登记记录新增", businessType = BusinessType.INSERT)
    @PostMapping("/sZlglCfdjSaleprescriptioninfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            pd.put("saleDocumentNumber", IdUtils.randomUUID());//销售单号
            pd.put("prescriptionNumber", IdUtils.randomUUID());//销售单号
            Integer result = sZlglCfdjSaleprescriptioninfoService.addSZlglCfdjSaleprescriptioninfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 处方登记记录 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("zlgl:zl:view")
    @GetMapping("/sZlglCfdjSaleprescriptioninfoView")
    public String szlglcfdjsaleprescriptioninfoListView() {
        return prefix + "/SZlglCfdjSaleprescriptioninfoList";
    }

    /**
    * 处方登记记录 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("zlgl:zl:list")
    @PostMapping("/sZlglCfdjSaleprescriptioninfoList")
    @ResponseBody
    public TableDataInfo szlglcfdjsaleprescriptioninfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sZlglCfdjSaleprescriptioninfoService.findSZlglCfdjSaleprescriptioninfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 处方登记记录 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("zlgl:zl:remove")
    @Log(title = "处方登记记录删除", businessType = BusinessType.DELETE)
    @PostMapping("/sZlglCfdjSaleprescriptioninfoRemove")
    @ResponseBody
    public AjaxResult szlglcfdjsaleprescriptioninfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sZlglCfdjSaleprescriptioninfoService.SZlglCfdjSaleprescriptioninfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 处方登记记录 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("zlgl:zl:edit")
    @GetMapping("/sZlglCfdjSaleprescriptioninfoEdit/{id}")
    public String szlglcfdjsaleprescriptioninfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sZlglCfdjSaleprescriptioninfoService.findSZlglCfdjSaleprescriptioninfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("editTage")){
            return prefix+ "/SZlglCfdjSaleprescriptioninfoPageEdit";
        }
        return prefix+ "/SZlglCfdjSaleprescriptioninfoEdit";
    }

    /**
    * 处方登记记录保存修改的数据
    */
    @RequiresPermissions("zlgl:zl:edit")
    @Log(title = "处方登记记录修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sZlglCfdjSaleprescriptioninfoEdit")
    @ResponseBody
    public AjaxResult szlglcfdjsaleprescriptioninfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sZlglCfdjSaleprescriptioninfoService.updateSZlglCfdjSaleprescriptioninfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表szlglcfdjsaleprescriptioninfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表szlglcfdjsaleprescriptioninfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
