package com.bzd.system.service;

import java.util.List;
import com.bzd.common.core.domain.Ztree;
import com.bzd.common.core.domain.entity.SysDept;
import com.bzd.common.core.domain.entity.SysRole;

/**
 * 门店管理 服务层
 *
 * @author LiXiagnFei
 */
public interface ISysDeptService
{
    /**
     * 查询门店管理数据
     *
     * @param dept 门店信息
     * @return 门店信息集合
     */
    public List<SysDept> selectDeptList(SysDept dept);

    /**
     * 查询门店管理树
     *
     * @param dept 门店信息
     * @return 所有门店信息
     */
    public List<Ztree> selectDeptTree(SysDept dept);

    /**
     * 查询门店管理树（排除下级）
     *
     * @param dept 门店信息
     * @return 所有门店信息
     */
    public List<Ztree> selectDeptTreeExcludeChild(SysDept dept);

    /**
     * 根据角色ID查询菜单
     *
     * @param role 角色对象
     * @return 菜单列表
     */
    public List<Ztree> roleDeptTreeData(SysRole role);

    /**
     * 根据父门店ID查询下级门店数量
     *
     * @param parentId 父门店ID
     * @return 结果
     */
    public int selectDeptCount(Long parentId);

    /**
     * 查询门店是否存在用户
     *
     * @param deptId 门店ID
     * @return 结果 true 存在 false 不存在
     */
    public boolean checkDeptExistUser(Long deptId);

    /**
     * 删除门店管理信息
     *
     * @param deptId 门店ID
     * @return 结果
     */
    public int deleteDeptById(Long deptId);

    /**
     * 新增保存门店信息
     *
     * @param dept 门店信息
     * @return 结果
     */
    public int insertDept(SysDept dept);

    /**
     * 修改保存门店信息
     *
     * @param dept 门店信息
     * @return 结果
     */
    public int updateDept(SysDept dept);

    /**
     * 根据门店ID查询信息
     *
     * @param deptId 门店ID
     * @return 门店信息
     */
    public SysDept selectDeptById(Long deptId);

    /**
     * 根据ID查询所有子门店（正常状态）
     *
     * @param deptId 门店ID
     * @return 子门店数
     */
    public int selectNormalChildrenDeptById(Long deptId);

    /**
     * 校验门店名称是否唯一
     *
     * @param dept 门店信息
     * @return 结果
     */
    public boolean checkDeptNameUnique(SysDept dept);

    /**
     * 校验门店是否有数据权限
     *
     * @param deptId 门店id
     */
    public void checkDeptDataScope(Long deptId);
}
